import ipywidgets as widgets
import sys
from IPython.display import display
from IPython.display import clear_output

from ipywidgets import interact

def create_multipleChoice_widget(description, options, correct_answer):
    if correct_answer not in options:
        options.append(correct_answer)

    correct_answer_index = options.index(correct_answer)

    radio_options = [(words, i) for i, words in enumerate(options)]
    alternativ = widgets.RadioButtons(
        options = radio_options,
        description = '',
        disabled = False
    )

    description_out = widgets.Output()
    with description_out:
        print(description)

    feedback_out = widgets.Output()

    def check_selection(b):
        a = int(alternativ.value)
        if a==correct_answer_index:
            s = '\x1b[6;30;42m' + "Riktig." + '\x1b[0m' +"\n" #green color
        else:
            s = '\x1b[5;30;41m' + "Feil. " + '\x1b[0m' +"\n" #red color
        with feedback_out:
            clear_output()
            print(s)
        return

    check = widgets.Button(description="submit")
    check.on_click(check_selection)


    return widgets.VBox([description_out, alternativ, check, feedback_out])


Q1 = create_multipleChoice_widget('blablabla',['apple','banana','pear'],'pear')
Q2 = create_multipleChoice_widget('lalalalal',['cat','dog','mouse'],'dog')
Q3 = create_multipleChoice_widget('jajajajaj',['blue','white','red'],'white')



import os
import pydicom
from .. import eval as _e
import ipywidgets as widgets


from ipywidgets import interact
def get_tags(mod):
    import sqlite3 as sq
    conn = sq.connect(os.path.join(_e.__DBDIR__,mod+".sqlite"))
    c = conn.cursor()
    c.execute("""SELECT tags FROM dmquestions""")
    tags = [t[0] for t in c.fetchall()]
    return tags

_tags = get_tags("m4")
_m4c_groups = ['qbank1', 'qbank2', 'qbank3', 'qbank4']
_m4c_evals = {key:[t for t in _tags if key in t] for key in _m4c_groups}

__scores = {key:{} for key in _m4c_evals.keys()}

del _tags

question_banks = {key:{tag:_e.create_question_widget("m4", tag) for tag in _m4c_evals[key]}
                     for key in _m4c_evals.keys() }



import sqlite3 as sq
import ipywidgets as widgets
from ipywidgets import interact
from IPython.display import clear_output
import os
import random
from datetime import datetime
from . __init__ import _score_db
import markdown

__PERMISSIVE__ = True
__DBDIR__ = os.path.join(os.path.abspath(os.path.dirname(__file__)), ".dbs")

def get_rw_feedback(a, answers):
    if answers[a][1]:
        s = '\x1b[6;30;42m' + "correct: %s"%answers[a][2] + '\x1b[0m' +"\n" #green color
        rslt = True
    else:
        s = '\x1b[5;30;41m' + "incorrect: %s"%answers[a][2] + '\x1b[0m' +"\n" #red color
        rslt = False
    return s, rslt


def record_response(qid, response, rslt):

    _sconn = sq.connect(_score_db)
    _sconn.execute("""INSERT INTO
                       scores (qid, result, response, time)
                       VALUES (?,?,?,?)""",(qid, rslt,
                                            response, datetime.now()))
    _sconn.commit()
    _sconn.close()



def assemble_ch_widget(question, answers):
    description = widgets.HTML(markdown.markdown(question))
    feedback = widgets.Output()
    check = widgets.Button(description="submit")
    options = [(a[0], i) for i, a in enumerate(answers)]

    choices = widgets.RadioButtons(
        options = options,
        description = '',
        disabled = False
    )
    return widgets.VBox([description, choices,
                         check, feedback])


def assemble_fr_widget(question):
    description = widgets.HTML(markdown.markdown(question))
    feedback = widgets.HTML()
    check = widgets.Button(description="submit")

    answer = widgets.Textarea(
                value='',
                placeholder='Type something',
                description='String:',
                disabled=False
            )
    return widgets.VBox([description, answer,
                         check, feedback])


def get_fr_widget(q, answer):

    question = q[1]
    question_tag = q[0]
    def record_answer(b):
        resp = _wdgs.children[1].value
        _wdgs.children[3].value = markdown.markdown(answer[2])
        record_response(question_tag, resp, None)


    _wdgs = assemble_fr_widget(question)
    _wdgs.children[2].on_click(record_answer)

    return _wdgs

def get_ch_widget(q, answers):

    question = q[1]
    question_tag = q[0]
    def check_selection(b):
        a = int(_wdgs.children[1].value)
        s, rslt = get_rw_feedback(a, answers)

        with _wdgs.children[3]:
            _wdgs.children[3].clear_output()
            print(s)
        record_response(question_tag, question, rslt)


    _wdgs = assemble_ch_widget(question, answers)
    _wdgs.children[2].on_click(check_selection)
    return _wdgs


def create_question_widget(mod, tag):

    conn = sq.connect(os.path.join(__DBDIR__,mod+".sqlite"))
    cursor = conn.cursor()
    cursor.execute("""SELECT
                      dmquestions.rowid,
                      dmquestions.question,
                      questiontype.type,
                      dmquestions.tags
                  FROM
                      dmquestions INNER JOIN
                          questiontype ON dmquestions.type=questiontype.rowid
                   WHERE tags = ?""",(tag,))
    q0 = cursor.fetchone()

    question_tag = q0[3]

    cursor.execute("""SELECT
                         answer, status, feedback
                      FROM
                         dmanswers
                      WHERE
                         dmanswers.qid=?""",(q0[0],))
    question_answers = cursor.fetchall()

    if q0[2] == "TF":
        w = get_ch_widget(q0, question_answers)
    elif q0[2] == "MC":
        random.shuffle(question_answers)
        w = get_ch_widget(q0, question_answers)
    elif q0[2] == "AT":
        w = get_at_widget(q0, question_answers)
    else:
        w =  get_fr_widget(q0, question_answers[0])
    conn.close()
    return w



import os
import sqlite3 as sq
from .version import __version__


_score_dir = os.path.join(os.path.expanduser("~"), ".dminteract")
if not os.path.exists(_score_dir):
    os.mkdir(_score_dir)

_score_db = os.path.join(_score_dir, "scores.sqlite")

if not os.path.exists(_score_db):
    _sconn = sq.connect(_score_db)
    _sc = _sconn.cursor()
    _sc.execute("""CREATE TABLE IF NOT EXISTS
                       scores (qid INT,
                               result BOOL,
                               response TEXT,
                               time DATE)""")
    _sconn.commit()
    _sconn.close()



import os
from .. import eval as _e


def get_tags(mod):
    import sqlite3 as sq
    conn = sq.connect(os.path.join(_e.__DBDIR__,mod+".sqlite"))
    c = conn.cursor()
    c.execute("""SELECT tags FROM dmquestions""")
    tags = [t[0] for t in c.fetchall()]
    return tags

_tags = get_tags("m5")
_m5_groups = ['qbank1', 'qbank2', 'qbank3']
_m5_evals = {key:[t for t in _tags if key in t] for key in _m5_groups}

__scores = {key:{} for key in _m5_evals.keys()}

del _tags

question_banks = {key:{tag:_e.create_question_widget("m5", tag) for tag in _m5_evals[key]}
                     for key in _m5_evals.keys() }
